@@ -457,7 +457,7 @@ nops_eval_write <- function(results = "nops_eval.csv", file = "nops_eval.zip",
   '<head>',
   paste0('<title>', lang$ExamResults, '</title>'),
   '<style type="text/css">',
-  'body{font-family:Arial;}',
+  'body{font-family: Arial, Helvetica, Sans;}',
   '</style>',
   '</head>',
   '',
